==> segatex-5.40.tgz: segatex-5.40/src/ausearch_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef AUSEARCHPROCESS_H
#define AUSEARCHPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qlabel.h> 
#include <qtextedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

class AusearchProcess: public QDialog 
{
	Q_OBJECT
public:
	AusearchProcess(QWidget *parent = 0, const char *name = 0);
	void ausearch_base_process(QString ausearch_str_pp_str);
public slots:
signals:
protected:
private slots:
	void readFromOutputFile();
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif

==> segatex-6.20.tgz: segatex-6.20/src/ausearch_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef AUSEARCHPROCESS_H
#define AUSEARCHPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qlabel.h> 
#include <qtextedit.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>

class AusearchProcess: public QDialog 
{
	Q_OBJECT
public:
	AusearchProcess(QWidget *parent = 0, const char *name = 0);
	void ausearch_base_process(QString ausearch_str_pp_str);
public slots:
signals:
protected:
private slots:
	void readFromOutputFile(QString ausearch_str_pp_str);
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;
        QString ausearch_str_pp_str_echo;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif
